## 公募基金持仓数据

接口：fund_portfolio

描述：获取公募基金持仓数据，季度更新

积分：5000积分以上每分钟请求200次，8000积分以上每分钟请求500次，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 基金代码 |
| symbol | str | N | 股票代码 |
| ann_date | str | N | 公告日期（YYYYMMDD格式） |
| period | str | N | 季度（每个季度最后一天的日期，比如20131231表示2013年年报） |
| start_date | str | N | 报告期开始日期（YYYYMMDD格式） |
| end_date | str | N | 报告期结束日期（YYYYMMDD格式） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS基金代码 |
| ann_date | str | Y | 公告日期 |
| end_date | str | Y | 截止日期 |
| symbol | str | Y | 股票代码 |
| mkv | float | Y | 持有股票市值(元) |
| amount | float | Y | 持有股票数量（股） |
| stk_mkv_ratio | float | Y | 占股票市值比 |
| stk_float_ratio | float | Y | 占流通股本比例 |

接口示例

```python
pro = ts.pro_api()

df = pro.fund_portfolio(ts_code='001753.OF')
```

数据示例

```python
ts_code  ann_date  end_date     symbol          mkv    amount  \
0    001753.OF  20180823  20180630  603019.SH   3130994.46   68258.0   
```